@@ -35,13 +35,13 @@ var searchData=
   ['checknan_32',['CheckNan',['../structopenvdb_1_1v11__0_1_1tools_1_1CheckNan.html',1,'openvdb::v11_0::tools']]],
   ['checknormgrad_33',['CheckNormGrad',['../structopenvdb_1_1v11__0_1_1tools_1_1CheckNormGrad.html',1,'openvdb::v11_0::tools']]],
   ['checkrange_34',['CheckRange',['../structopenvdb_1_1v11__0_1_1tools_1_1CheckRange.html',1,'openvdb::v11_0::tools']]],
-  ['childall_35',['childall',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildAll.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildAll'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildAll.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildAll']]],
-  ['childiter_36',['childiter',['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; ValueMask, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; bool, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildIter.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildIter&lt; NodeT, ChildT, MaskIterT, TagT &gt;'],['../classnanovdb_1_1RootNode_1_1ChildIter.html',1,'RootNode&lt; ChildT &gt;::ChildIter&lt; RootT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildIter.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT, TagT &gt;'],['../classnanovdb_1_1InternalNode_1_1ChildIter.html',1,'InternalNode&lt; ChildT, Log2Dim &gt;::ChildIter&lt; ParentT &gt;']]],
-  ['childiterator_37',['childiterator',['../classnanovdb_1_1build_1_1InternalNode_1_1ChildIterator.html',1,'InternalNode&lt; ChildT &gt;::ChildIterator'],['../classnanovdb_1_1build_1_1RootNode_1_1ChildIterator.html',1,'RootNode&lt; ChildT &gt;::ChildIterator']]],
+  ['childall_35',['ChildAll',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildAll.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildAll'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildAll.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildAll']]],
+  ['childiter_36',['ChildIter',['../classnanovdb_1_1InternalNode_1_1ChildIter.html',1,'InternalNode&lt; ChildT, Log2Dim &gt;::ChildIter&lt; ParentT &gt;'],['../classnanovdb_1_1RootNode_1_1ChildIter.html',1,'RootNode&lt; ChildT &gt;::ChildIter&lt; RootT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildIter.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildIter&lt; NodeT, ChildT, MaskIterT, TagT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildIter.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT, TagT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_3_01bool_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; bool, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_3_01ValueMask_00_01Log2Dim_01_4_1_1ChildIter.html',1,'LeafNode&lt; ValueMask, Log2Dim &gt;::ChildIter&lt; MaskIterT, NodeT &gt;']]],
+  ['childiterator_37',['ChildIterator',['../classnanovdb_1_1build_1_1InternalNode_1_1ChildIterator.html',1,'InternalNode&lt; ChildT &gt;::ChildIterator'],['../classnanovdb_1_1build_1_1RootNode_1_1ChildIterator.html',1,'RootNode&lt; ChildT &gt;::ChildIterator']]],
   ['childnodetype_38',['ChildNodeType',['../structnanovdb_1_1LeafNode_1_1ChildNodeType.html',1,'nanovdb::LeafNode']]],
-  ['childoff_39',['childoff',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildOff.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOff'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildOff.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOff']]],
-  ['childon_40',['childon',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildOn.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOn'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildOn.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOn']]],
-  ['cli_41',['cli',['../structopenvdb_1_1v11__0_1_1ax_1_1PointExecutable_1_1CLI.html',1,'PointExecutable::CLI'],['../structopenvdb_1_1v11__0_1_1ax_1_1VolumeExecutable_1_1CLI.html',1,'VolumeExecutable::CLI']]],
+  ['childoff_39',['ChildOff',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildOff.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOff'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildOff.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOff']]],
+  ['childon_40',['ChildOn',['../structopenvdb_1_1v11__0_1_1tree_1_1InternalNode_1_1ChildOn.html',1,'InternalNode&lt; _ChildNodeType, Log2Dim &gt;::ChildOn'],['../structopenvdb_1_1v11__0_1_1tree_1_1LeafNode_1_1ChildOn.html',1,'LeafNode&lt; T, Log2Dim &gt;::ChildOn']]],
+  ['cli_41',['CLI',['../structopenvdb_1_1v11__0_1_1ax_1_1PointExecutable_1_1CLI.html',1,'PointExecutable::CLI'],['../structopenvdb_1_1v11__0_1_1ax_1_1VolumeExecutable_1_1CLI.html',1,'VolumeExecutable::CLI']]],
   ['clierror_42',['CLIError',['../classopenvdb_1_1v11__0_1_1CLIError.html',1,'openvdb::v11_0']]],
   ['closestpointprojector_43',['ClosestPointProjector',['../classopenvdb_1_1v11__0_1_1tools_1_1ClosestPointProjector.html',1,'openvdb::v11_0::tools']]],
   ['closestsurfacepoint_44',['ClosestSurfacePoint',['../classopenvdb_1_1v11__0_1_1tools_1_1ClosestSurfacePoint.html',1,'openvdb::v11_0::tools']]],
@@ -112,27 +112,29 @@ var searchData=
   ['converttrait_3c_20nanovdb_3a_3avaluemask_20_3e_109',['ConvertTrait&lt; nanovdb::ValueMask &gt;',['../structConvertTrait_3_01nanovdb_1_1ValueMask_01_4.html',1,'']]],
   ['converttrait_3c_20nanovdb_3a_3avec3_3c_20t_20_3e_20_3e_110',['ConvertTrait&lt; nanovdb::Vec3&lt; T &gt; &gt;',['../structConvertTrait_3_01nanovdb_1_1Vec3_3_01T_01_4_01_4.html',1,'']]],
   ['converttrait_3c_20nanovdb_3a_3avec4_3c_20t_20_3e_20_3e_111',['ConvertTrait&lt; nanovdb::Vec4&lt; T &gt; &gt;',['../structConvertTrait_3_01nanovdb_1_1Vec4_3_01T_01_4_01_4.html',1,'']]],
-  ['coord_112',['coord',['../classnanovdb_1_1Coord.html',1,'Coord'],['../classopenvdb_1_1v11__0_1_1math_1_1Coord.html',1,'Coord']]],
+  ['coord_112',['Coord',['../classnanovdb_1_1Coord.html',1,'Coord'],['../classopenvdb_1_1v11__0_1_1math_1_1Coord.html',1,'Coord']]],
   ['coordbbox_113',['CoordBBox',['../classopenvdb_1_1v11__0_1_1math_1_1CoordBBox.html',1,'openvdb::v11_0::math']]],
   ['copyableopapplier_114',['CopyableOpApplier',['../classopenvdb_1_1v11__0_1_1tools_1_1valxform_1_1CopyableOpApplier.html',1,'openvdb::v11_0::tools::valxform']]],
-  ['copyconstness_115',['CopyConstness',['../structopenvdb_1_1v11__0_1_1CopyConstness.html',1,'openvdb::v11_0']]],
-  ['copyfromdense_116',['CopyFromDense',['../classopenvdb_1_1v11__0_1_1tools_1_1CopyFromDense.html',1,'openvdb::v11_0::tools']]],
-  ['copyiterator_117',['copyiterator',['../structopenvdb_1_1v11__0_1_1points_1_1point__move__internal_1_1GlobalMovePointsOp_1_1CopyIterator.html',1,'GlobalMovePointsOp&lt; TreeT &gt;::CopyIterator'],['../structopenvdb_1_1v11__0_1_1points_1_1point__move__internal_1_1LocalMovePointsOp_1_1CopyIterator.html',1,'LocalMovePointsOp&lt; TreeT &gt;::CopyIterator']]],
-  ['copyop_118',['CopyOp',['../structopenvdb_1_1v11__0_1_1math_1_1pcg_1_1internal_1_1CopyOp.html',1,'openvdb::v11_0::math::pcg::internal']]],
-  ['copytodense_119',['CopyToDense',['../classopenvdb_1_1v11__0_1_1tools_1_1CopyToDense.html',1,'openvdb::v11_0::tools']]],
-  ['cpt_120',['cpt',['../structopenvdb_1_1v11__0_1_1math_1_1CPT.html',1,'CPT&lt; MapType, DiffScheme &gt;'],['../classopenvdb_1_1v11__0_1_1tools_1_1Cpt.html',1,'Cpt&lt; InGridT, MaskGridType, InterruptT &gt;']]],
-  ['cpt_5frange_121',['CPT_RANGE',['../structopenvdb_1_1v11__0_1_1math_1_1CPT__RANGE.html',1,'openvdb::v11_0::math']]],
-  ['cputimer_122',['cputimer',['../classnanovdb_1_1CpuTimer.html',1,'CpuTimer'],['../classopenvdb_1_1v11__0_1_1util_1_1CpuTimer.html',1,'CpuTimer']]],
-  ['createnanogrid_123',['CreateNanoGrid',['../classnanovdb_1_1CreateNanoGrid.html',1,'nanovdb']]],
-  ['crement_124',['Crement',['../structopenvdb_1_1v11__0_1_1ax_1_1ast_1_1Crement.html',1,'openvdb::v11_0::ax::ast']]],
-  ['csgdifferenceop_125',['CsgDifferenceOp',['../structopenvdb_1_1v11__0_1_1tools_1_1CsgDifferenceOp.html',1,'openvdb::v11_0::tools']]],
-  ['csgunionorintersectionop_126',['CsgUnionOrIntersectionOp',['../structopenvdb_1_1v11__0_1_1tools_1_1CsgUnionOrIntersectionOp.html',1,'openvdb::v11_0::tools']]],
-  ['curl_127',['curl',['../classopenvdb_1_1v11__0_1_1tools_1_1Curl.html',1,'Curl&lt; GridT, MaskGridType, InterruptT &gt;'],['../structopenvdb_1_1v11__0_1_1math_1_1Curl.html',1,'Curl&lt; MapType, DiffScheme &gt;']]],
-  ['curl_3c_20uniformscalemap_2c_20cd_5f2nd_20_3e_128',['Curl&lt; UniformScaleMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
-  ['curl_3c_20uniformscalemap_2c_20diffscheme_20_3e_129',['Curl&lt; UniformScaleMap, DiffScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01DiffScheme_01_4.html',1,'openvdb::v11_0::math']]],
-  ['curl_3c_20uniformscaletranslatemap_2c_20cd_5f2nd_20_3e_130',['Curl&lt; UniformScaleTranslateMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleTranslateMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
-  ['curl_3c_20uniformscaletranslatemap_2c_20diffscheme_20_3e_131',['Curl&lt; UniformScaleTranslateMap, DiffScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleTranslateMap_00_01DiffScheme_01_4.html',1,'openvdb::v11_0::math']]],
-  ['curvaturestencil_132',['curvaturestencil',['../classnanovdb_1_1CurvatureStencil.html',1,'CurvatureStencil&lt; GridT, RealT &gt;'],['../classopenvdb_1_1v11__0_1_1math_1_1CurvatureStencil.html',1,'CurvatureStencil&lt; GridT, IsSafe &gt;']]],
-  ['curvaturestencil_3c_20gridt_2c_20false_20_3e_133',['CurvatureStencil&lt; GridT, false &gt;',['../classopenvdb_1_1v11__0_1_1math_1_1CurvatureStencil.html',1,'openvdb::v11_0::math']]],
-  ['customdata_134',['CustomData',['../classopenvdb_1_1v11__0_1_1ax_1_1CustomData.html',1,'openvdb::v11_0::ax']]]
+  ['copyableoptransformer_115',['CopyableOpTransformer',['../classopenvdb_1_1v11__0_1_1tools_1_1valxform_1_1CopyableOpTransformer.html',1,'openvdb::v11_0::tools::valxform']]],
+  ['copyconstness_116',['CopyConstness',['../structopenvdb_1_1v11__0_1_1CopyConstness.html',1,'openvdb::v11_0']]],
+  ['copyfromdense_117',['CopyFromDense',['../classopenvdb_1_1v11__0_1_1tools_1_1CopyFromDense.html',1,'openvdb::v11_0::tools']]],
+  ['copyiterator_118',['CopyIterator',['../structopenvdb_1_1v11__0_1_1points_1_1point__move__internal_1_1GlobalMovePointsOp_1_1CopyIterator.html',1,'GlobalMovePointsOp&lt; TreeT &gt;::CopyIterator'],['../structopenvdb_1_1v11__0_1_1points_1_1point__move__internal_1_1LocalMovePointsOp_1_1CopyIterator.html',1,'LocalMovePointsOp&lt; TreeT &gt;::CopyIterator']]],
+  ['copyop_119',['CopyOp',['../structopenvdb_1_1v11__0_1_1math_1_1pcg_1_1internal_1_1CopyOp.html',1,'openvdb::v11_0::math::pcg::internal']]],
+  ['copytodense_120',['CopyToDense',['../classopenvdb_1_1v11__0_1_1tools_1_1CopyToDense.html',1,'openvdb::v11_0::tools']]],
+  ['cpt_121',['CPT',['../structopenvdb_1_1v11__0_1_1math_1_1CPT.html',1,'openvdb::v11_0::math']]],
+  ['cpt_122',['Cpt',['../classopenvdb_1_1v11__0_1_1tools_1_1Cpt.html',1,'openvdb::v11_0::tools']]],
+  ['cpt_5frange_123',['CPT_RANGE',['../structopenvdb_1_1v11__0_1_1math_1_1CPT__RANGE.html',1,'openvdb::v11_0::math']]],
+  ['cputimer_124',['CpuTimer',['../classnanovdb_1_1CpuTimer.html',1,'CpuTimer'],['../classopenvdb_1_1v11__0_1_1util_1_1CpuTimer.html',1,'CpuTimer']]],
+  ['createnanogrid_125',['CreateNanoGrid',['../classnanovdb_1_1CreateNanoGrid.html',1,'nanovdb']]],
+  ['crement_126',['Crement',['../structopenvdb_1_1v11__0_1_1ax_1_1ast_1_1Crement.html',1,'openvdb::v11_0::ax::ast']]],
+  ['csgdifferenceop_127',['CsgDifferenceOp',['../structopenvdb_1_1v11__0_1_1tools_1_1CsgDifferenceOp.html',1,'openvdb::v11_0::tools']]],
+  ['csgunionorintersectionop_128',['CsgUnionOrIntersectionOp',['../structopenvdb_1_1v11__0_1_1tools_1_1CsgUnionOrIntersectionOp.html',1,'openvdb::v11_0::tools']]],
+  ['curl_129',['Curl',['../structopenvdb_1_1v11__0_1_1math_1_1Curl.html',1,'Curl&lt; MapType, DiffScheme &gt;'],['../classopenvdb_1_1v11__0_1_1tools_1_1Curl.html',1,'Curl&lt; GridT, MaskGridType, InterruptT &gt;']]],
+  ['curl_3c_20uniformscalemap_2c_20cd_5f2nd_20_3e_130',['Curl&lt; UniformScaleMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
+  ['curl_3c_20uniformscalemap_2c_20diffscheme_20_3e_131',['Curl&lt; UniformScaleMap, DiffScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleMap_00_01DiffScheme_01_4.html',1,'openvdb::v11_0::math']]],
+  ['curl_3c_20uniformscaletranslatemap_2c_20cd_5f2nd_20_3e_132',['Curl&lt; UniformScaleTranslateMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleTranslateMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
+  ['curl_3c_20uniformscaletranslatemap_2c_20diffscheme_20_3e_133',['Curl&lt; UniformScaleTranslateMap, DiffScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Curl_3_01UniformScaleTranslateMap_00_01DiffScheme_01_4.html',1,'openvdb::v11_0::math']]],
+  ['curvaturestencil_134',['CurvatureStencil',['../classnanovdb_1_1CurvatureStencil.html',1,'CurvatureStencil&lt; GridT, RealT &gt;'],['../classopenvdb_1_1v11__0_1_1math_1_1CurvatureStencil.html',1,'CurvatureStencil&lt; GridT, IsSafe &gt;']]],
+  ['curvaturestencil_3c_20gridt_2c_20false_20_3e_135',['CurvatureStencil&lt; GridT, false &gt;',['../classopenvdb_1_1v11__0_1_1math_1_1CurvatureStencil.html',1,'openvdb::v11_0::math']]],
+  ['customdata_136',['CustomData',['../classopenvdb_1_1v11__0_1_1ax_1_1CustomData.html',1,'openvdb::v11_0::ax']]]
 ];
