@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: ":_abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvw",
-  2: "cdghlnopsu",
+  2: "cdghlnosu",
   3: "abcdefghilmnopqrstuv",
   4: "abcdefghijklmnopqrstuvwxyz~",
   5: "_abcdefghiklmnoprstuvwxy",
@@ -10,7 +10,7 @@ var indexSectionsWithContent =
   7: "abcdfgiklmnoprstv",
   8: "abcdefghiklmnopqrstuvwxyz",
   9: ":abcilmoprstv",
-  10: "_abcdeiklnoprtuv",
+  10: "_abcdeiknoprtuv",
   11: "abcdefhilmnopqrstuw"
 };
 
