@@ -1,7 +1,7 @@
 var searchData=
 [
   ['element_5fcount_0',['element_count',['../structpnanovdb__gridblindmetadata__t.html#a0d83e4c0da54dd6558fa319c85cf7f2d',1,'pnanovdb_gridblindmetadata_t']]],
-  ['elements_1',['elements',['../structopenvdb_1_1v11__0_1_1ValueTraits.html#a4995f0e20a31e0ed60a61a560e221b28',1,'openvdb::v11_0::ValueTraits::Elements'],['../structopenvdb_1_1v11__0_1_1ValueTraits_3_01T_00_01false_01_4.html#a4995f0e20a31e0ed60a61a560e221b28',1,'openvdb::v11_0::ValueTraits&lt; T, false &gt;::Elements']]],
+  ['elements_1',['Elements',['../structopenvdb_1_1v11__0_1_1ValueTraits.html#a4995f0e20a31e0ed60a61a560e221b28',1,'openvdb::v11_0::ValueTraits::Elements'],['../structopenvdb_1_1v11__0_1_1ValueTraits_3_01T_00_01false_01_4.html#a4995f0e20a31e0ed60a61a560e221b28',1,'openvdb::v11_0::ValueTraits&lt; T, false &gt;::Elements']]],
   ['empty_2',['EMPTY',['../classnanovdb_1_1GridChecksum.html#a73c46381146e35dbe69b7a8b0dda92d6',1,'nanovdb::GridChecksum']]],
   ['excludenames_3',['excludeNames',['../structopenvdb_1_1v11__0_1_1points_1_1RasterGroups.html#a73356781a279e13d61299cf6131ed900',1,'openvdb::v11_0::points::RasterGroups']]],
   ['explist_4',['explist',['../unionAXSTYPE.html#a926607e553cd7f7624ea4b58532f5252',1,'AXSTYPE']]],
